@@ -17,17 +17,17 @@ function(doses, N, cohort, icon, theta, model, simulatedData, TR, prob = 0.9, AU
     pstim_mean = list()
 
     if (model == "pktox" & is.null(betapriors)){
-    	betapriors = c(10000, 20, 10)
+    	betapriors = c(10, 10000, 20, 10)
     }else if(model == "pkcrm" & is.null(betapriors)){
-    	betapriors = 10000
+    	betapriors = c(10, 10000)
     }else if (model == "pkpop" & is.null(betapriors)){
-    	betapriors = c(10000, 10, 5)
+    	betapriors = c(10, 10000, 10, 5)
     }else if (model == "dtox" & is.null(betapriors)){
     	betapriors = c(6.71, 1.43)
     }else if(model == "pkcov" & is.null(betapriors)){
     	betapriors = c(-14.76, 3.23)
     }else if (model == "pklogit" & is.null(betapriors)){
-    	betapriors = c(10000, 20, 10)
+    	betapriors = c(10, 10000, 20, 10)
     }
 
 
